/*
 * This file is part of BlueMap, licensed under the MIT License (MIT).
 *
 * Copyright (c) Blue (Lukas Rieger) <https://bluecolored.de>
 * Copyright (c) contributors
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package de.bluecolored.bluemap.common.rendermanager;

import java.util.Optional;

public interface RenderTask {

    void doWork() throws Exception;

    /**
     * Whether this task is requesting more calls to its {@link #doWork()} method.<br>
     * This can be false because the task is finished, OR because the task got cancelled and decides to interrupt.
     */
    boolean hasMoreWork();

    /**
     * The estimated progress made so far, from 0 to 1.
     */
    default double estimateProgress() {
        return 0d;
    }

    /**
     * Requests to cancel this task. The task then self-decides what to do with this request.
     */
    void cancel();

    /**
     * Checks if the given task is somehow included with this task
     */
    default boolean contains(RenderTask task) {
        return equals(task);
    }

    String getDescription();

    default Optional<String> getDetail() {
        return Optional.empty();
    }

}
